@@ -1,5 +1,5 @@
 package Music::Intervals::Numeric;
-$Music::Intervals::Numeric::VERSION = '0.0803';
+$Music::Intervals::Numeric::VERSION = '0.0804';
 our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Breakdown of numeric musical intervals
@@ -16,7 +16,10 @@ use strictures 2;
 use namespace::clean;
 
 
-has notes => ( is => 'ro', default => sub { [] } );
+has notes => (
+    is => 'ro',
+    default => sub { [qw( 1/1 5/4 3/2 )] },
+);
 
 
 has ratios => (
@@ -149,7 +152,7 @@ Music::Intervals::Numeric - Breakdown of numeric musical intervals
 
 =head1 VERSION
 
-version 0.0803
+version 0.0804
 
 =head1 SYNOPSIS
 
